@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-05'; # DATE
+our $DATE = '2022-06-08'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 sub meta {
     +{
@@ -31,7 +31,7 @@ sub filter {
         "",
         "do {",
         "    my \$tmp = $dt; ",
-        "    if (\$tmp =~ m!\\A/.*/\\z!s) { my \$re = eval \"qr\$tmp\"; if (\$@) { [\"Invalid regex: \$@\", \$tmp] } else { [undef, \$re] } } ",
+        "    if (\$tmp =~ m!\\A/.*/(?:[ims]*)\\z!s) { my \$re = eval \"qr\$tmp\"; if (\$@) { [\"Invalid regex: \$@\", \$tmp] } else { [undef, \$re] } } ",
         "    else { [undef, \$tmp] } ",
         "}",
     );
@@ -54,7 +54,7 @@ Data::Sah::Filter::perl::Str::maybe_convert_to_re - Convert string to regex if s
 
 =head1 VERSION
 
-This document describes version 0.004 of Data::Sah::Filter::perl::Str::maybe_convert_to_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-05.
+This document describes version 0.005 of Data::Sah::Filter::perl::Str::maybe_convert_to_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
 
 =head1 DESCRIPTION
 
