@@ -3,15 +3,17 @@ package Sah::Schema::str_or_re;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-06-05'; # DATE
+our $DATE = '2022-06-08'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [any => {
     summary => 'String or regex (if string is of the form `/.../`)',
     description => <<'_',
 
 If string is of the form of `/.../`, then it will be parsed as a regex.
+Currently modifiers `i`, `m`, and `s` after the second `/` are allowed.
+
 Otherwise, it's accepted as a plain string.
 
 _
@@ -28,8 +30,9 @@ _
         {value=>{}, valid=>0, summary=>'Not a string'},
 
         {value=>'//', valid=>1, validated_value=>qr//},
-        {value=>'/foo', valid=>1},
+        {value=>'/foo', valid=>1, summary=>'Becomes a string'},
         {value=>'/foo.*/', valid=>1, validated_value=>qr/foo.*/},
+        {value=>'/foo/is', valid=>1, validated_value=>qr/foo/is},
         {value=>'/foo[/', valid=>0, summary=>'Invalid regex'},
     ],
 
@@ -50,7 +53,7 @@ Sah::Schema::str_or_re - String or regex (if string is of the form `/.../`)
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-05.
+This document describes version 0.005 of Sah::Schema::str_or_re (from Perl distribution Sah-Schemas-Str), released on 2022-06-08.
 
 =head1 SYNOPSIS
 
@@ -127,11 +130,15 @@ Sample data:
 
  "/foo.*/"  # valid, becomes qr(foo.*)
 
+ "/foo/is"  # valid, becomes qr(foo)si
+
  "/foo[/"  # INVALID (Invalid regex)
 
 =head1 DESCRIPTION
 
 If string is of the form of C</.../>, then it will be parsed as a regex.
+Currently modifiers C<i>, C<m>, and C<s> after the second C</> are allowed.
+
 Otherwise, it's accepted as a plain string.
 
 =head1 HOMEPAGE
